@@ -1,6 +1,7 @@
 """Functions for creating and managing k8s resources"""
 from __future__ import annotations
 
+import copy
 import functools
 import json
 import logging
@@ -506,6 +507,9 @@ def await_k8s_job_completion(spec: dict, tail: Optional[int] = None) -> bool:
     """Wait for k8s job to complete
     :param spec: dict with job parameters. Must contain 'NAMESPACE', 'JOB_NAME', 'MODE' keys.
     :param tail: num of lines to print from job logs on completion. Defaults to k8s default
+    :raises ValueError: if missing parameters from spec
+    :raises RuntimeError: if k8s job failed to complete
+    :return: True if k8s job succeeded
     """
     namespace = spec.get('NAMESPACE')
     if not namespace:
@@ -600,6 +604,73 @@ def await_k8s_job_completion(spec: dict, tail: Optional[int] = None) -> bool:
     raise RuntimeError(f'{name=}, {terminal_status=}')
 
 
+# todo: add tests
+def scale_resources_to_zero(
+        resources: Mapping, prefix: str, namespace: Optional[str] = 'default-tenant', mode: Optional[str] = None,
+        logger: Optional[logging.Logger] = None,
+) -> None:
+    """Scale to zero given resources
+
+    :param resources:
+    :param prefix: string prefix for spec lookups
+    :param namespace: namespace of the resources
+    :param mode: execution mode
+    :param logger: logger object
+    """
+    logger_plain = log.get_logger('plain')
+    kubectl = Executable('kubectl', 'kubectl -n', namespace, logger=logger_plain)
+    labels_to_await = []
+    mode = mode or 'dry-run'
+    logger = logger or log.get_logger()
+    if not resources.get(prefix + '_SERVICE_REPLICAS_SCALE_TO_ZERO', True):
+        logger.warning('service replicas scale to zero is disabled')
+        return
+    if mode == 'normal':
+        from basepak import confirm
+        confirm.default()
+
+    dry_run_option = '--dry-run=server' if mode == 'dry-run' else ''
+    if labels := resources.get('LABEL_SELECTOR_DEPLOYMENTS'):
+        if isinstance(labels, str):
+            labels = [labels]
+        for selector in labels:
+            if not kubectl.run(f'get deployment --{selector=}', check=False).stdout.strip():
+                logger.warning(f'No deployment found in --{namespace=} --{selector=}')
+                logger.warning(f'Skipping scale...')
+                continue
+            labels_to_await.append(selector)
+            kubectl.stream(f'scale deployment --replicas=0 --{selector=}', dry_run_option)
+
+    if labels := resources.get('LABEL_SELECTOR_STATEFULSETS'):
+        if isinstance(labels, str):
+            labels = [labels]
+        for selector in labels:
+            if not kubectl.run(f'get statefulset --{selector=}', check=False).stdout.strip():
+                logger.warning(f'No statefulset found in --{namespace=} --{selector=}')
+                logger.warning(f'Skipping scale...')
+                continue
+            labels_to_await.append(selector)
+            kubectl.stream(f'scale statefulset --replicas=0 --{selector=}', dry_run_option)
+
+    logger.info('Waiting for pods to terminate')
+    if mode == 'dry-run':
+        return
+    from time import monotonic
+    start_time = monotonic()
+    for selector in labels_to_await:
+        get_pods_cmd = f'get pods --{selector=}'
+        pods = kubectl.run(get_pods_cmd).stdout.strip()
+        while pods:
+            logger_plain.info(pods)
+            if start_time - monotonic() > 3600:
+                raise TimeoutError(f'Termination timeout for pods at --{namespace=} --{selector=} ')
+            time.sleep(10)
+            pod_lines = kubectl.run(get_pods_cmd).stdout.strip().splitlines()
+            if len(pod_lines) <= 1:
+                break
+            pods = '\n'.join(pod_lines[1:])
+
+
 # deprecated
 def _check_gibby_logs_for_container_hang(job_name: str, namespace: str, kubectl: Executable, retries: int,
                                          logger: logging.Logger) -> int:
@@ -847,14 +918,13 @@ def prep_binary(mode: str, spec: dict, name: str, refresh_rate_default) -> str:
         image = spec['JOB_IMAGE']
         namespace = spec['NAMESPACE']
         path_on_image = spec['PATH_ON_IMAGE']
-        image_pull_policy = spec.get('IMAGE_PULL_POLICY')
 
         logger = log.get_logger()
         logger.warning(f'{name} path not set in manifest or found in PATH. Checking in temp dir')
         path = os.path.join(temp_dir, name)
 
         set_image_pull_policy_default(spec, refresh_rate_default)
-        if image_pull_policy == 'Always':
+        if spec.get('IMAGE_PULL_POLICY') == 'Always':
             logger.warning(f'Force updating from k8s image')
             swap_path = path + '.swap'
             fetch_from_image(namespace, image, path_on_image, swap_path, mode)
@@ -912,6 +982,11 @@ def get_size_on_remote(spec, path) -> str:
     :param path: the remote path to measure
     :return: du -sh size result or empty string
     """
+    spec = copy.deepcopy(spec)
+    spec.pop('JOB_NAME', None)
+    spec.pop('JOB_IMAGE', None)
+    spec.pop('ARGS', None)
+    spec.pop('ENV_VARS', None)
     if spec['DISK_TOTALS'] not in ['yes', 'remote']:
         return ''
     logger = log.get_logger('plain')
@@ -922,5 +997,5 @@ def get_size_on_remote(spec, path) -> str:
     logger.error(resp.stderr)
     logger.info(resp.stdout)
     if size := next((x.strip() for x in resp.stdout.strip().splitlines() if x), ''):
-        return size.split()[0]
+        return size.split()[0].strip().replace("'", "")
     return ''
